@@ -8,33 +8,6 @@ from redis import Redis
 from werkzeug.datastructures import CallbackDict
 from flask.sessions import SessionInterface, SessionMixin
 
-# def get_lang(lang):
-#     '''
-#     优先使用 用户设定 lang
-#     其次使用 用户设定中cookie的 lang
-#     没有时使用session中保存的
-#     最后才用 浏览器中的lang 语言设定
-#
-#     :param lang:
-#     :return:
-#     '''
-#     if lang is None:
-#         lang = request.cookies.get('local')
-#     if lang is None:
-#         lang = session.get('locale')
-#     if lang is None:
-#         return request.accept_languages.best_match(['zh-TW','zh-CN', 'en','vi-VN'])
-#     if lang.lower() in('cn','zh_cn','zh-cn'):
-#         return 'zh-CN'
-#     elif lang.lower() in('tw','zh_tw','zh-tw'):
-#         return 'zh-TW'
-#     elif lang.lower() =='en':
-#         return 'en'
-#     elif lang.lower() in ('vi-vn','vi'):
-#         return 'vi-VN'
-#     else:
-#         return lang
-
 class RedisSession(CallbackDict, SessionMixin):
     def __init__(self, initial=None, sid=None, new=False):
         def on_update(self):
@@ -45,6 +18,8 @@ class RedisSession(CallbackDict, SessionMixin):
         self.new = new
         self.modified = False
         self.seend_cookie = True
+        # 某些临时session的过期时间会比较短或长
+        self.temp_expiration_time = 0
 
 class RedisSessionInterface(SessionInterface):
     session_class = RedisSession
@@ -74,6 +49,8 @@ class RedisSessionInterface(SessionInterface):
     def get_redis_expiration_time(self, app, session):
         if session.permanent:
             return app.permanent_session_lifetime
+        if session.temp_expiration_time>0:
+            return timedelta(seconds=session.temp_expiration_time)
         return timedelta(days=2)
 
     def get_session(self,sid):
@@ -124,3 +101,4 @@ class RedisSessionInterface(SessionInterface):
             #                     )
             # 确保下次正常时需要
             session.seend_cookie = False
+            session.temp_expiration_time = 0
